@@ -31,7 +31,7 @@ if pkgutil.find_loader("matplotlib"):
 else:
     logging.error("matplotlib is not available. This can lead some features of PM4Py to not work correctly!")
 
-__version__ = '1.5.2.1'
+__version__ = '1.5.2.2'
 __doc__ = "Process Mining for Python (PM4Py)"
 __author__ = 'Fraunhofer Institute for Applied Technology'
 __author_email__ = 'pm4py@fit.fraunhofer.de'
@@ -50,5 +50,6 @@ from pm4py.vis import view_petri_net, save_vis_petri_net, view_dfg, save_vis_dfg
     save_vis_process_tree, \
     view_heuristics_net, save_vis_heuristics_net
 from pm4py.filtering import filter_start_activities, filter_end_activities, filter_attribute_values, filter_variants, \
-    filter_variants_percentage, filter_paths, filter_timestamp
-from pm4py.stats import get_start_activities, get_end_activities, get_attributes, get_attribute_values, get_variants
+    filter_variants_percentage, filter_paths, filter_timestamp, filter_trace_attribute
+from pm4py.stats import get_start_activities, get_end_activities, get_attributes, get_attribute_values, get_variants, \
+    get_trace_attributes
