@@ -20,7 +20,7 @@ import numpy as np
 
 from pm4py import util as pm4pyutil
 from pm4py.objects import petri
-from pm4py.objects.petri.importer import pnml as petri_importer
+from pm4py.objects.petri.importer import importer as petri_importer
 from pm4py.objects.log import log as log_implementation
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
 from pm4py.objects.petri.synchronous_product import construct_cost_aware
