@@ -10,7 +10,7 @@ DEFAULT_VARIANT = CLASSIC
 VERSIONS = {CLASSIC: classic.apply}
 
 @deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use algorithm entrypoint instead')
+                        details='Use algorithm entrypoint instead (discovery/log_skeleton/factory)')
 def apply(log, variant=DEFAULT_VARIANT, parameters=None):
     """
     Discover a log skeleton from an event log
