@@ -1,10 +1,12 @@
-from pm4py import util as pmutil
-from pm4py.algo.conformance.tokenreplay import factory as token_replay
+from pm4py.algo.conformance.tokenreplay.versions import token_replay
+from pm4py.algo.conformance.tokenreplay import algorithm as executor
+
 from pm4py.objects import log as log_lib
 from pm4py.evaluation.precision import utils as precision_utils
 from pm4py.statistics.start_activities.log.get import get_start_activities
 from pm4py.objects.petri.align_utils import get_visible_transitions_eventually_enabled_by_marking
-from pm4py.util.constants import PARAMETER_TOKEN_REPLAY_VARIANT, DEFAULT_TOKEN_REPLAY_VARIANT
+from pm4py.evaluation.precision.parameters import Parameters
+from pm4py.util import exec_utils
 
 """
 Implementation of the approach described in paper
@@ -24,10 +26,6 @@ At the moment, the precision value is different from the one provided by the Pro
 although the implementation seems to follow the paper concept
 """
 
-PARAM_ACTIVITY_KEY = pmutil.constants.PARAMETER_CONSTANT_ACTIVITY_KEY
-
-PARAMETERS = [PARAM_ACTIVITY_KEY]
-
 
 def apply(log, net, marking, final_marking, parameters=None):
     """
@@ -45,37 +43,35 @@ def apply(log, net, marking, final_marking, parameters=None):
         Final marking
     parameters
         Parameters of the algorithm, including:
-            pm4py.util.constants.PARAMETER_CONSTANT_ACTIVITY_KEY -> Activity key
+            Parameters.ACTIVITY_KEY -> Activity key
     """
 
     if parameters is None:
         parameters = {}
 
-    cleaning_token_flood = parameters["cleaning_token_flood"] if "cleaning_token_flood" in parameters else False
-    token_replay_variant = parameters[
-        PARAMETER_TOKEN_REPLAY_VARIANT] if PARAMETER_TOKEN_REPLAY_VARIANT in parameters else DEFAULT_TOKEN_REPLAY_VARIANT
-
-    activity_key = parameters[
-        PARAM_ACTIVITY_KEY] if PARAM_ACTIVITY_KEY in parameters else log_lib.util.xes.DEFAULT_NAME_KEY
+    cleaning_token_flood = exec_utils.get_param_value(Parameters.CLEANING_TOKEN_FLOOD, parameters, False)
+    token_replay_variant = exec_utils.get_param_value(Parameters.TOKEN_REPLAY_VARIANT, parameters,
+                                                      executor.Variants.TOKEN_REPLAY)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, log_lib.util.xes.DEFAULT_NAME_KEY)
     # default value for precision, when no activated transitions (not even by looking at the initial marking) are found
     precision = 1.0
     sum_ee = 0
     sum_at = 0
 
     parameters_tr = {
-        "consider_remaining_in_fitness": False,
-        "try_to_reach_final_marking_through_hidden": False,
-        "stop_immediately_unfit": True,
-        "walk_through_hidden_trans": True,
-        "cleaning_token_flood": cleaning_token_flood,
-        PARAM_ACTIVITY_KEY: activity_key
+        token_replay.Parameters.CONSIDER_REMAINING_IN_FITNESS: False,
+        token_replay.Parameters.TRY_TO_REACH_FINAL_MARKING_THROUGH_HIDDEN: False,
+        token_replay.Parameters.STOP_IMMEDIATELY_UNFIT: True,
+        token_replay.Parameters.WALK_THROUGH_HIDDEN_TRANS: True,
+        token_replay.Parameters.CLEANING_TOKEN_FLOOD: cleaning_token_flood,
+        token_replay.Parameters.ACTIVITY_KEY: activity_key
     }
 
     prefixes, prefix_count = precision_utils.get_log_prefixes(log, activity_key=activity_key)
     prefixes_keys = list(prefixes.keys())
     fake_log = precision_utils.form_fake_log(prefixes_keys, activity_key=activity_key)
 
-    aligned_traces = token_replay.apply(fake_log, net, marking, final_marking, variant=token_replay_variant,
+    aligned_traces = executor.apply(fake_log, net, marking, final_marking, variant=token_replay_variant,
                                         parameters=parameters_tr)
 
     # fix: also the empty prefix should be counted!
