@@ -47,7 +47,7 @@ def import_from_file(file_path, parameters=None):
     if parameters is None:
         parameters = {}
 
-    from pm4py.objects.log.importer.parquet import factory as parquet_importer
+    from pm4py.objects.log.importer.parquet import importer as parquet_importer
     dataframe = parquet_importer.apply(file_path, parameters=parameters)
 
     return dataframe
