@@ -1,2 +1,2 @@
 from pm4py.util import lp, versions, constants, points_subset, business_hours, regex, xes_constants, vis_utils, \
-    dt_parsing, colors, exec_utils
+    dt_parsing, colors, exec_utils, pandas_utils
